@@ -170,7 +170,11 @@ get_datasets.sites <- function(x, ...) {
   } else {
     all_data <- TRUE
   }
-  output <- get_datasets(x = ids, all_data = all_data, ...)
+  dots <- list(...)
+  if ("all_data" %in% names(dots)) {
+    dots$all_data <- NULL
+  }
+  output <- get_datasets(x = ids, all_data = all_data)
   return(output)
 }
 
@@ -202,6 +206,17 @@ get_datasets.site <- function(x, ...) {
   } else {
     all_data <- TRUE
   }
+  dots <- list(...)
+  if ("all_data" %in% names(dots)) {
+    dots$all_data <- NULL
+  }
   output <- get_datasets(dataset_list, all_data = all_data)
   return(output)
+}
+
+#' @rdname get_datasets
+#' @exportS3Method get_datasets NULL
+get_datasets.NULL <- function(x, ...) {
+  message("Input is NULL, returning NULL")
+  return(NULL)
 }
\ No newline at end of file
